# cr-api-py
Python wrapper for cr-api.com

[![Build Status](https://travis-ci.org/smlbiobot/cr-api-py.svg?branch=master)](https://travis-ci.org/smlbiobot/cr-api-py)

Docs at https://smlbiobot.github.io/cr-api-py/